@@ -2,7 +2,7 @@
 //! in a mass spectrum.
 //!
 //! It's meant to be used as a building block for other tools and does not provide
-//! any I/O machinery for peak lists
+//! any I/O machinery for peak lists. For that, consider [`mzdata`](https://crates.io/crates/mzdata)
 //!
 //! ```rust
 //! use mzpeaks::{CentroidPeak, PeakSet, PeakCollection, MassErrorType};
@@ -24,19 +24,23 @@
 //!```
 
 pub mod coordinate;
+#[macro_use]
+pub mod macros;
 pub mod mass_error;
 pub mod peak;
 pub mod peak_set;
+pub mod peak_index;
 pub mod prelude;
 #[cfg(test)]
 mod test_data;
 
 pub use crate::coordinate::{
-    CoordinateDimension, CoordinateLike, IndexType, IndexedCoordinate, Mass, MZ,
+    CoordinateDimension, CoordinateLike, IndexType, IndexedCoordinate, MZLocated, Mass,
+    MassLocated, MZ,
 };
 pub use crate::mass_error::MassErrorType;
 pub use crate::peak::{
-    CentroidLike, CentroidPeak, DeconvolutedCentroid, DeconvolutedPeak, IntensityMeasurement,
+    CentroidLike, CentroidPeak, DeconvolutedCentroidLike, DeconvolutedPeak, IntensityMeasurement,
 };
 pub use crate::peak_set::{
     DeconvolutedPeakSet, MZPeakSetType, MassPeakSetType, PeakCollection, PeakSet,
